import * as i0 from '@angular/core';
import { InjectionToken, Component, Inject, HostListener, NgModule, Injector, Injectable } from '@angular/core';
import * as i1 from '@angular/cdk/overlay';
import { OverlayModule, OverlayConfig } from '@angular/cdk/overlay';
import { ComponentPortal } from '@angular/cdk/portal';
import { Subject } from 'rxjs';
import { CommonModule } from '@angular/common';

const IMAGE_OVERLAY_DATA_TOKEN = new InjectionToken('IMAGE_OVERLAY_DATA');
class AngularMaterialImageOverlayComponent {
    constructor(imageOverlayData) {
        this.imageOverlayData = imageOverlayData;
        this.currentImageIndex = 0;
        this.onKeydown = new Subject();
        this.onClose = new Subject();
        this.images = imageOverlayData.images;
        this.currentImageIndex = this.obtainCurrentImageIndex(imageOverlayData.currentImage);
        this.currentImage = this.images[this.currentImageIndex];
    }
    obtainCurrentImageIndex(dataCurrentImage) {
        if (dataCurrentImage) {
            return this.images.indexOf(dataCurrentImage);
        }
        return 0;
    }
    handleKeydown(event) {
        this.onKeydown.next(event.key);
    }
    close() {
        this.onClose.next();
    }
    nextImage() {
        if (this.currentImageIndex < this.images.length - 1) {
            this.currentImageIndex++;
            this.currentImage = this.images[this.currentImageIndex];
        }
    }
    previousImage() {
        if (this.currentImageIndex > 0) {
            this.currentImageIndex--;
            this.currentImage = this.images[this.currentImageIndex];
        }
    }
}
AngularMaterialImageOverlayComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayComponent, deps: [{ token: IMAGE_OVERLAY_DATA_TOKEN }], target: i0.ɵɵFactoryTarget.Component });
AngularMaterialImageOverlayComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.14", type: AngularMaterialImageOverlayComponent, selector: "ng-component", host: { listeners: { "document:keydown": "handleKeydown($event)" } }, ngImport: i0, template: "<img class=\"angular-material-image-overlay-image\" [src]=\"currentImage\">\n<div class=\"angular-material-image-overlay-close\" (click)=\"close()\">Close</div>", styles: [".angular-material-image-overlay-image{border:3px solid gray;height:auto;max-width:500px;width:100%}.angular-material-image-overlay-close{background-color:#696969;border:1px solid slategray;color:#fff;cursor:pointer;font-family:\"Lucida Sans\",\"Lucida Sans Regular\",\"Lucida Grande\",\"Lucida Sans Unicode\",Geneva,Verdana,sans-serif;font-size:small;font-weight:bold;margin:auto;padding:.5em;text-align:center;width:4em}.angular-material-image-overlay-close:hover{background-color:#708090;border:1px solid slategray;color:#fff;cursor:pointer;font-family:\"Lucida Sans\",\"Lucida Sans Regular\",\"Lucida Grande\",\"Lucida Sans Unicode\",Geneva,Verdana,sans-serif;font-size:small;font-weight:bold;margin:auto;padding:.5em;text-align:center;width:4em}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayComponent, decorators: [{
            type: Component,
            args: [{
                    templateUrl: './angular-material-image-overlay.component.html',
                    styleUrls: ['./angular-material-image-overlay.component.scss']
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [IMAGE_OVERLAY_DATA_TOKEN]
                }] }]; }, propDecorators: { handleKeydown: [{
                type: HostListener,
                args: ['document:keydown', ['$event']]
            }] } });

class AngularMaterialImageOverlayModule {
}
AngularMaterialImageOverlayModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AngularMaterialImageOverlayModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayModule, declarations: [AngularMaterialImageOverlayComponent], imports: [CommonModule,
        OverlayModule], exports: [AngularMaterialImageOverlayComponent] });
AngularMaterialImageOverlayModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayModule, imports: [[
            CommonModule,
            OverlayModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        AngularMaterialImageOverlayComponent
                    ],
                    imports: [
                        CommonModule,
                        OverlayModule
                    ],
                    exports: [
                        AngularMaterialImageOverlayComponent
                    ]
                }]
        }] });

class AngularMaterialImageOverlayService {
    constructor(injector, overlay) {
        this.injector = injector;
        this.overlay = overlay;
    }
    buildInjector(images, currentImage) {
        const imageOverlayData = { images: images, currentImage: currentImage };
        return Injector.create({
            providers: [{ provide: IMAGE_OVERLAY_DATA_TOKEN, useValue: imageOverlayData }],
            parent: this.injector
        });
    }
    buildOverlayConfig() {
        const result = new OverlayConfig();
        result.hasBackdrop = true;
        result.positionStrategy = this.overlay.position().global().centerVertically().centerHorizontally();
        return result;
    }
    open(images, currentImage) {
        const imagesInjector = this.buildInjector(images, currentImage);
        const imagePortal = new ComponentPortal(AngularMaterialImageOverlayComponent, null, imagesInjector);
        this.overlayRef = this.overlay.create(this.buildOverlayConfig());
        this.overlayRef.backdropClick().subscribe(() => this.overlayRef.dispose());
        this.imageOverlayComponentRef = this.overlayRef.attach(imagePortal);
        this.imageOverlayComponentRef.instance.onKeydown.subscribe(keycode => this.onKeydown(keycode));
        this.imageOverlayComponentRef.instance.onClose.subscribe(() => this.overlayRef.dispose());
    }
    onKeydown(keycode) {
        switch (keycode) {
            case ('ArrowRight'):
            case ('ArrowDown'):
                this.imageOverlayComponentRef.instance.nextImage();
                break;
            case ('ArrowLeft'):
            case ('ArrowUp'):
                this.imageOverlayComponentRef.instance.previousImage();
                break;
            case ('Escape'):
                this.overlayRef.dispose();
        }
    }
}
AngularMaterialImageOverlayService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayService, deps: [{ token: i0.Injector }, { token: i1.Overlay }], target: i0.ɵɵFactoryTarget.Injectable });
AngularMaterialImageOverlayService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayService, providedIn: AngularMaterialImageOverlayModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: AngularMaterialImageOverlayService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: AngularMaterialImageOverlayModule
                }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i1.Overlay }]; } });

/*
 * Public API Surface of angular-material-image-overlay
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularMaterialImageOverlayComponent, AngularMaterialImageOverlayModule, AngularMaterialImageOverlayService, IMAGE_OVERLAY_DATA_TOKEN };
//# sourceMappingURL=angular-material-image-overlay.js.map
